summaryrefslogtreecommitdiff
path: root/include/llvm/Use.h
diff options
context:
space:
mode:
authorChris Lattner <sabre@nondot.org>2005-01-30 00:09:23 +0000
committerChris Lattner <sabre@nondot.org>2005-01-30 00:09:23 +0000
commitbca81448ac8e19c588c9a4ad16fc70732b76327c (patch)
treeeb4d515aa88a94cc20e36908ff4336a032129399 /include/llvm/Use.h
parent5c3fa1ec79b3e37e364641a995e08e0ddd933372 (diff)
downloadllvm-bca81448ac8e19c588c9a4ad16fc70732b76327c.tar.gz
llvm-bca81448ac8e19c588c9a4ad16fc70732b76327c.tar.bz2
llvm-bca81448ac8e19c588c9a4ad16fc70732b76327c.tar.xz
Improve conformance with the Misha spelling benchmark suite
git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@19930 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'include/llvm/Use.h')
-rw-r--r--include/llvm/Use.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/include/llvm/Use.h b/include/llvm/Use.h
index 3eeea92e91..26923a26da 100644
--- a/include/llvm/Use.h
+++ b/include/llvm/Use.h
@@ -84,12 +84,12 @@ struct ilist_traits<Use> {
static void setPrev(Use *N, Use *Prev) { N->UseLinks.Prev = Prev; }
static void setNext(Use *N, Use *Next) { N->UseLinks.Next = Next; }
/// createSentinal - this is used to create the end marker for the use list.
/// Note that we only allocate a UseLinks structure, which is just enough to
/// hold the next/prev pointers. This saves us 8 bytes of memory for every
/// Value allocated.
- static Use *createSentinal() { return (Use*)new Use::NextPrevPtrs(); }
- static void destroySentinal(Use *S) { delete (Use::NextPrevPtrs*)S; }
+ static Use *createSentinel() { return (Use*)new Use::NextPrevPtrs(); }
+ static void destroySentinel(Use *S) { delete (Use::NextPrevPtrs*)S; }
void addNodeToList(Use *NTy) {}
void removeNodeFromList(Use *NTy) {}
@@ -84,12 +84,12 @@ struct ilist_traits<Use> {
static void setPrev(Use *N, Use *Prev) { N->UseLinks.Prev = Prev; }
static void setNext(Use *N, Use *Next) { N->UseLinks.Next = Next; }
- /// createSentinal - this is used to create the end marker for the use list.
+ /// createSentinel - this is used to create the end marker for the use list.
/// Note that we only allocate a UseLinks structure, which is just enough to
/// hold the next/prev pointers. This saves us 8 bytes of memory for every